# devpi-json-info - JSON Info Plugin for devpi

## Origin

This plugin is based on a work @fschulze based on a question on
stackoverflow: https://stackoverflow.com/questions/63711923/devpi-how-to-get-root-package-json-served?noredirect=1#comment113022032_63711923

## Purpose

The plugin serves the infos for a Python package in JSON format.
This feature is e.g. used by micropython-upip.


